@@ -8,11 +8,12 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.Adjustment;
 import org.gnu.gtk.SelectionMode;
 /**
- *
+ * @deprecated
  */
 public class IconList extends Canvas {
 	/**
@@ -22,7 +23,7 @@ public class IconList extends Canvas {
 		super(init(iconWidth, adj, isEditable, isStaticText));
 	}
 	
-	private static int init(int iconWidth, Adjustment adj, boolean isEditable, boolean isStaticText) {
+	private static Handle init(int iconWidth, Adjustment adj, boolean isEditable, boolean isStaticText) {
 		int flags = 0;
 		if (isEditable)
 			flags = flags & 1 << 0;
@@ -34,7 +35,7 @@ public class IconList extends Canvas {
 	/**
 	 * Construct a new IconList from a handle to a native resource.
 	 */
-	public IconList(int handle) {
+	public IconList(Handle handle) {
 	    super(handle);
 	}
 	
@@ -207,45 +208,41 @@ public class IconList extends Canvas {
 		return new Type(gnome_icon_list_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_icon_list_get_type();
-	native static final protected int gnome_icon_list_new(int iconWidth, int adj, int flags);
-	native static final protected void gnome_icon_list_set_hadjustment(int gil, int hadj);
-	native static final protected void gnome_icon_list_set_vadjustment(int gil, int vadj);
-	native static final protected void gnome_icon_list_freeze(int gil);
-	native static final protected void gnome_icon_list_thaw(int gil);
-	native static final protected void gnome_icon_list_insert(int gil, int idx, String iconFilename, String text);
-	native static final protected void gnome_icon_list_insert_pixbuf(int gil, int idx, int im, String iconFilename, String text);
-	native static final protected int gnome_icon_list_append(int gil, String iconFilename, String text);
-	native static final protected int gnome_icon_list_append_pixbuf(int gil, int im, String iconFilename, String text);
-	native static final protected void gnome_icon_list_clear(int gil);
-	native static final protected void gnome_icon_list_remove(int gil, int idx);
-	native static final protected int gnome_icon_list_get_num_icons(int gil);
-	native static final protected int gnome_icon_list_get_selection_mode(int gil);
-	native static final protected void gnome_icon_list_set_selection_mode(int gil, int mode);
-	native static final protected void gnome_icon_list_select_icon(int gil, int idx);
-	native static final protected void gnome_icon_list_unselect_icon(int gil, int idx);
-	native static final protected void gnome_icon_list_select_all(int gil);
-	native static final protected int gnome_icon_list_unselect_all(int gil);
-	native static final protected int gnome_icon_list_get_selection(int gil);
-	native static final protected void gnome_icon_list_focus_icon(int gil, int idx);
-	native static final protected void gnome_icon_list_set_icon_width(int gil, int w);
-	native static final protected void gnome_icon_list_set_row_spacing(int gil, int pixels);
-	native static final protected void gnome_icon_list_set_col_spacing(int gil, int pixels);
-	native static final protected void gnome_icon_list_set_text_spacing(int gil, int pixels);
-	native static final protected void gnome_icon_list_set_icon_border(int gil, int pixels);
-	native static final protected void gnome_icon_list_set_separators(int gil, String sep);
-	native static final protected String gnome_icon_list_get_icon_filename(int gil, int idx);
-	native static final protected int gnome_icon_list_find_icon_from_filename(int gil, String filename);
-	native static final protected void gnome_icon_list_moveto(int gil, int idx, double yalign);
-	native static final protected int gnome_icon_list_icon_is_visible(int gil, int idx);
-	native static final protected int gnome_icon_list_get_icon_at(int gil, int x, int y);
-	native static final protected int gnome_icon_list_get_items_per_line(int gil);
-	native static final protected int gnome_icon_list_get_icon_text_item(int gil, int idx);
-	native static final protected int gnome_icon_list_get_icon_pixbuf_item(int gil, int idx);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_icon_list_new(int iconWidth, Handle adj, int flags);
+	native static final protected void gnome_icon_list_set_hadjustment(Handle gil, Handle hadj);
+	native static final protected void gnome_icon_list_set_vadjustment(Handle gil, Handle vadj);
+	native static final protected void gnome_icon_list_freeze(Handle gil);
+	native static final protected void gnome_icon_list_thaw(Handle gil);
+	native static final protected void gnome_icon_list_insert(Handle gil, int idx, String iconFilename, String text);
+	native static final protected void gnome_icon_list_insert_pixbuf(Handle gil, int idx, int im, String iconFilename, String text);
+	native static final protected int gnome_icon_list_append(Handle gil, String iconFilename, String text);
+	native static final protected int gnome_icon_list_append_pixbuf(Handle gil, Handle im, String iconFilename, String text);
+	native static final protected void gnome_icon_list_clear(Handle gil);
+	native static final protected void gnome_icon_list_remove(Handle gil, int idx);
+	native static final protected int gnome_icon_list_get_num_icons(Handle gil);
+	native static final protected int gnome_icon_list_get_selection_mode(Handle gil);
+	native static final protected void gnome_icon_list_set_selection_mode(Handle gil, int mode);
+	native static final protected void gnome_icon_list_select_icon(Handle gil, int idx);
+	native static final protected void gnome_icon_list_unselect_icon(Handle gil, int idx);
+	native static final protected void gnome_icon_list_select_all(Handle gil);
+	native static final protected int gnome_icon_list_unselect_all(Handle gil);
+	native static final protected Handle[] gnome_icon_list_get_selection(Handle gil);
+	native static final protected void gnome_icon_list_focus_icon(Handle gil, int idx);
+	native static final protected void gnome_icon_list_set_icon_width(Handle gil, int w);
+	native static final protected void gnome_icon_list_set_row_spacing(Handle gil, int pixels);
+	native static final protected void gnome_icon_list_set_col_spacing(Handle gil, int pixels);
+	native static final protected void gnome_icon_list_set_text_spacing(Handle gil, int pixels);
+	native static final protected void gnome_icon_list_set_icon_border(Handle gil, int pixels);
+	native static final protected void gnome_icon_list_set_separators(Handle gil, String sep);
+	native static final protected String gnome_icon_list_get_icon_filename(Handle gil, int idx);
+	native static final protected int gnome_icon_list_find_icon_from_filename(Handle gil, String filename);
+	native static final protected void gnome_icon_list_moveto(Handle gil, int idx, double yalign);
+	native static final protected int gnome_icon_list_icon_is_visible(Handle gil, int idx);
+	native static final protected int gnome_icon_list_get_icon_at(Handle gil, int x, int y);
+	native static final protected int gnome_icon_list_get_items_per_line(Handle gil);
+	native static final protected Handle gnome_icon_list_get_icon_text_item(Handle gil, int idx);
+	native static final protected Handle gnome_icon_list_get_icon_pixbuf_item(Handle gil, int idx);
+
 }
